pub struct Multipart { /* private fields */ }Expand description
Extractor that parses multipart/form-data requests (commonly used with file uploads).
โ ๏ธ Since extracting multipart form data from the request requires consuming the body, the
Multipart extractor must be last if there are multiple extractors in a handler.
See โthe order of extractorsโ
Example
use axum::{
extract::Multipart,
routing::post,
Router,
};
use futures_util::stream::StreamExt;
async fn upload(mut multipart: Multipart) {
while let Some(mut field) = multipart.next_field().await.unwrap() {
let name = field.name().unwrap().to_string();
let data = field.bytes().await.unwrap();
println!("Length of `{}` is {} bytes", name, data.len());
}
}
let app = Router::new().route("/upload", post(upload));Implementations
Sourceimpl Multipart
impl Multipart
Sourcepub async fn next_field(&mut self) -> Result<Option<Field<'_>>, MultipartError>
pub async fn next_field(&mut self) -> Result<Option<Field<'_>>, MultipartError>
Yields the next Field if available.